==> wisp_python-0.5.1-py3-none-any.whl: wisp/server/__main__.py <==
import argparse
import asyncio
import logging

try:
  import uvloop
  use_uvloop = True
except ImportError:
  use_uvloop = False

import wisp
import wisp.server.http

if __name__ == "__main__":
  parser = argparse.ArgumentParser(
    prog="wisp-server-python",
    description=f"A Wisp server implementation, written in Python (v{wisp.version})"
  )

  parser.add_argument("--host", default="127.0.0.1", help="The hostname the server will listen on.")
  parser.add_argument("--port", default=6001, help="The TCP port the server will listen on.")
  parser.add_argument("--static", help="Where static files are served from.")
  parser.add_argument("--limits", action="store_true", help="Enable rate limits.")
  parser.add_argument("--bandwidth", default=1000, help="Bandwidth limit per IP, in kilobytes per second.")
  parser.add_argument("--connections", default=30, help="New connections limit per IP.")
  parser.add_argument("--window", default=60, help="Fixed window length for rate limits, in seconds.")
  parser.add_argument("--allow-loopback", action="store_true",help="Allow connections to loopback IP addresses.")
  parser.add_argument("--allow-private", action="store_true", help="Allow connections to private IP addresses.")
  parser.add_argument("--log-level", default="info", help="The log level (either debug, info, warning, error, or critical).")
  args = parser.parse_args()

  logging.basicConfig(
    format="[%(asctime)s] %(levelname)-8s %(message)s",
    level=getattr(logging, args.log_level.upper()),
    datefmt="%Y/%m/%d - %H:%M:%S"
  )

  if use_uvloop:
    uvloop.run(wisp.server.http.main(args))
  else:
    logging.error("Importing uvloop failed. Falling back to asyncio, which is slower.")
    asyncio.run(wisp.server.http.main(args))

==> wisp_python-0.5.2-py3-none-any.whl: wisp/server/__main__.py <==
import argparse
import asyncio
import logging
import sys

try:
  import uvloop
  use_uvloop = True
except ImportError:
  use_uvloop = False

import wisp
import wisp.server.http

if __name__ == "__main__":
  parser = argparse.ArgumentParser(
    prog="wisp-server-python",
    description=f"A Wisp server implementation, written in Python (v{wisp.version})"
  )

  parser.add_argument("--host", default="127.0.0.1", help="The hostname the server will listen on.")
  parser.add_argument("--port", default=6001, help="The TCP port the server will listen on.")
  parser.add_argument("--static", help="Where static files are served from.")
  parser.add_argument("--limits", action="store_true", help="Enable rate limits.")
  parser.add_argument("--bandwidth", default=1000, help="Bandwidth limit per IP, in kilobytes per second.")
  parser.add_argument("--connections", default=30, help="New connections limit per IP.")
  parser.add_argument("--window", default=60, help="Fixed window length for rate limits, in seconds.")
  parser.add_argument("--allow-loopback", action="store_true",help="Allow connections to loopback IP addresses.")
  parser.add_argument("--allow-private", action="store_true", help="Allow connections to private IP addresses.")
  parser.add_argument("--log-level", default="info", help="The log level (either debug, info, warning, error, or critical).")
  args = parser.parse_args()

  logging.basicConfig(
    format="[%(asctime)s] %(levelname)-8s %(message)s",
    level=getattr(logging, args.log_level.upper()),
    datefmt="%Y/%m/%d - %H:%M:%S"
  )

  if use_uvloop:
    uvloop.run(wisp.server.http.main(args))
  else:
    #uvloop doesn't support windows at all so we don't need to print the error
    if not sys.platform in ("win32", "cygwin"):
      logging.error("Importing uvloop failed. Falling back to asyncio, which is slower.")
    asyncio.run(wisp.server.http.main(args))
